package com.ruoyi.dw.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.dw.domain.DwAnswer;
import com.ruoyi.dw.service.IDwAnswerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 调查问卷答案Controller
 * 
 * @author sunyg
 * @date 2025-06-26
 */
@RestController
@RequestMapping("/dw/answer")
public class  DwAnswerController extends BaseController
{
    @Autowired
    private IDwAnswerService dwAnswerService;

    /**
     * 查询调查问卷答案列表
     */
    @GetMapping("/list")
    public TableDataInfo list(DwAnswer dwAnswer)
    {
        startPage();
        List<DwAnswer> list = dwAnswerService.selectDwAnswerList(dwAnswer);
        return getDataTable(list);
    }

    /**
     * 导出调查问卷答案列表
     */
    @Log(title = "调查问卷答案", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DwAnswer dwAnswer)
    {
        List<DwAnswer> list = dwAnswerService.selectDwAnswerList(dwAnswer);
        ExcelUtil<DwAnswer> util = new ExcelUtil<DwAnswer>(DwAnswer.class);
        util.exportExcel(response, list, "调查问卷答案数据");
    }

    /**
     * 获取调查问卷答案详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dwAnswerService.selectDwAnswerById(id));
    }

    /**
     * 新增调查问卷答案
     */
    @Log(title = "调查问卷答案", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DwAnswer dwAnswer)
    {
        return toAjax(dwAnswerService.insertDwAnswer(dwAnswer));
    }

    /**
     * 修改调查问卷答案
     */
    @Log(title = "调查问卷答案", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DwAnswer dwAnswer)
    {
        return toAjax(dwAnswerService.updateDwAnswer(dwAnswer));
    }

    /**
     * 删除调查问卷答案
     */
    @Log(title = "调查问卷答案", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dwAnswerService.deleteDwAnswerByIds(ids));
    }

}
