package com.ruoyi.dw.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.dw.domain.DwInfo;
import com.ruoyi.dw.domain.DwQuestion;
import com.ruoyi.dw.service.IDwInfoService;
import com.ruoyi.dw.service.IDwQuestionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 调查问卷问题Controller
 * 
 * @author sunyg
 * @date 2025-06-26
 */
@RestController
@RequestMapping("/dw/question")
public class DwQuestionController extends BaseController
{
    @Autowired
    private IDwQuestionService dwQuestionService;

    @Resource
    private IDwInfoService dwInfoService;

    /**
     * 查询调查问卷问题列表
     */
    @GetMapping("/list")
    public TableDataInfo list(DwQuestion dwQuestion)
    {
        startPage();
        List<DwQuestion> list = dwQuestionService.selectDwQuestionList(dwQuestion);
        return getDataTable(list);
    }

    /**
     * 调查问卷问题列表下拉框选择
     */
    @GetMapping("/select")
    public AjaxResult select()
    {
        List<DwQuestion> list = dwQuestionService.selectDwQuestionList(new DwQuestion());
        return AjaxResult.success(list);
    }

    /**
     * 导出调查问卷问题列表
     */
    @Log(title = "调查问卷问题", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DwQuestion dwQuestion)
    {
        List<DwQuestion> list = dwQuestionService.selectDwQuestionList(dwQuestion);
        ExcelUtil<DwQuestion> util = new ExcelUtil<DwQuestion>(DwQuestion.class);
        util.exportExcel(response, list, "调查问卷问题数据");
    }

    /**
     * 获取调查问卷问题详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dwQuestionService.selectDwQuestionById(id));
    }

    /**
     * 新增调查问卷问题
     */
    @Log(title = "调查问卷问题", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DwQuestion dwQuestion)
    {
        return toAjax(dwQuestionService.insertDwQuestion(dwQuestion));
    }

    /**
     * 修改调查问卷问题
     */
    @Log(title = "调查问卷问题", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DwQuestion dwQuestion)
    {
        return toAjax(dwQuestionService.updateDwQuestion(dwQuestion));
    }

    /**
     * 删除调查问卷问题
     */
    @Log(title = "调查问卷问题", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dwQuestionService.deleteDwQuestionByIds(ids));
    }


    /**
     * 导入调查问卷数据
     * @param file
     * @param infoId
     * @return
     * @throws Exception
     */
    @PostMapping("/import")
    public AjaxResult importData(MultipartFile file, Long infoId) throws Exception{
        DwInfo dwInfo = dwInfoService.selectDwInfoById(infoId);
        if (dwInfo == null) {
            return AjaxResult.error("导入的调查问卷不存在，请重新选择");
        }
        int successNum = dwQuestionService.importData(file, dwInfo);
        if (successNum > 0) {
            return AjaxResult.success();
        }else {
            return AjaxResult.error("导入失败，请检查调查问卷内容是否正确");
        }
    }

}
