package com.ruoyi.dw.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.dw.domain.DwAnswer;
import com.ruoyi.dw.domain.DwInfo;
import com.ruoyi.dw.mapper.DwAnswerMapper;
import com.ruoyi.dw.mapper.DwInfoMapper;
import org.apache.poi.ss.usermodel.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.dw.mapper.DwQuestionMapper;
import com.ruoyi.dw.domain.DwQuestion;
import com.ruoyi.dw.service.IDwQuestionService;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;

/**
 * 调查问卷问题Service业务层处理
 * 
 * @author sunyg
 * @date 2025-06-26
 */
@Service
public class DwQuestionServiceImpl implements IDwQuestionService 
{
    @Autowired
    private DwQuestionMapper dwQuestionMapper;

    @Resource
    private DwAnswerMapper dwAnswerMapper;

    @Resource
    private RedisCache redisCache;

    /**
     * 查询调查问卷问题
     * 
     * @param id 调查问卷问题主键
     * @return 调查问卷问题
     */
    @Override
    public DwQuestion selectDwQuestionById(Long id)
    {
        return dwQuestionMapper.selectDwQuestionById(id);
    }

    /**
     * 查询调查问卷问题列表
     * 
     * @param dwQuestion 调查问卷问题
     * @return 调查问卷问题
     */
    @Override
    public List<DwQuestion> selectDwQuestionList(DwQuestion dwQuestion)
    {
        return dwQuestionMapper.selectDwQuestionList(dwQuestion);
    }

    /**
     * 新增调查问卷问题
     * 
     * @param dwQuestion 调查问卷问题
     * @return 结果
     */
    @Override
    public int insertDwQuestion(DwQuestion dwQuestion)
    {
        return dwQuestionMapper.insertDwQuestion(dwQuestion);
    }

    /**
     * 修改调查问卷问题
     * 
     * @param dwQuestion 调查问卷问题
     * @return 结果
     */
    @Override
    public int updateDwQuestion(DwQuestion dwQuestion)
    {
        return dwQuestionMapper.updateDwQuestion(dwQuestion);
    }

    /**
     * 批量删除调查问卷问题
     * 
     * @param ids 需要删除的调查问卷问题主键
     * @return 结果
     */
    @Override
    public int deleteDwQuestionByIds(Long[] ids)
    {
        return dwQuestionMapper.deleteDwQuestionByIds(ids);
    }

    /**
     * 删除调查问卷问题信息
     * 
     * @param id 调查问卷问题主键
     * @return 结果
     */
    @Override
    public int deleteDwQuestionById(Long id)
    {
        return dwQuestionMapper.deleteDwQuestionById(id);
    }

    @Override
    public int importData(MultipartFile file, DwInfo dwInfo) {
        try {
            Workbook workbook = WorkbookFactory.create(file.getInputStream());
            Sheet sheet = workbook.getSheetAt(0);
            int rows = sheet.getLastRowNum();
            if (rows <= 0){
                return -1;
            }
            List<DwAnswer> answers = new ArrayList<DwAnswer>();
            for (int i = 1; i <= rows; i++) {
                //第一个调查问卷问题
                Row row = sheet.getRow(i);
                String id = row.getCell(0).getStringCellValue();
                if (redisCache.hasKey(id)){
                    continue;
                }
                if (dwInfo.getId().intValue() == 1) {
                    DwAnswer answer1 = new DwAnswer();
                    Cell cell15 = row.getCell(15);
                    answer1.setAnswer(cell15.getStringCellValue());
                    answer1.setInfoId(dwInfo.getId());
                    answer1.setQuestionId(1L);
                    answers.add(answer1);
                    DwAnswer answer2 = new DwAnswer();
                    Cell cell16 = row.getCell(16);
                    answer2.setAnswer(cell16.getStringCellValue());
                    answer2.setInfoId(dwInfo.getId());
                    answer2.setQuestionId(2L);
                    answers.add(answer2);
                    DwAnswer answer3 = new DwAnswer();
                    Cell cell17 = row.getCell(17);
                    answer3.setAnswer(cell17.getStringCellValue());
                    answer3.setInfoId(dwInfo.getId());
                    answer3.setQuestionId(3L);
                    answers.add(answer3);
                    DwAnswer answer4 = new DwAnswer();
                    Cell cell18 = row.getCell(18);
                    answer4.setAnswer(cell18.getStringCellValue());
                    answer4.setInfoId(dwInfo.getId());
                    answer4.setQuestionId(4L);
                    answers.add(answer4);
                    DwAnswer answer5 = new DwAnswer();
                    Cell cell19 = row.getCell(19);
                    answer5.setAnswer(cell19.getStringCellValue());
                    answer5.setInfoId(dwInfo.getId());
                    answer5.setQuestionId(5L);
                    answers.add(answer5);
                    DwAnswer answer6 = new DwAnswer();
                    Cell cell20 = row.getCell(20);
                    answer6.setAnswer(cell20.getStringCellValue());
                    answer6.setInfoId(dwInfo.getId());
                    answer6.setQuestionId(6L);
                    answers.add(answer6);
                    DwAnswer answer7 = new DwAnswer();
                    Cell cell21 = row.getCell(21);
                    Cell cell22 = row.getCell(22);
                    if (cell22 != null && StringUtils.isNotEmpty(cell22.getStringCellValue())){
                        answer7.setAnswer(cell22.getStringCellValue());
                    }else {
                        answer7.setAnswer(cell21.getStringCellValue());
                    }
                    answer7.setInfoId(dwInfo.getId());
                    answer7.setQuestionId(7L);
                    answers.add(answer7);
                    DwAnswer answer8 = new DwAnswer();
                    Cell cell23 = row.getCell(23);
                    Cell cell24 = row.getCell(24);
                    if (cell24 != null && StringUtils.isNotEmpty(cell24.getStringCellValue())){
                        answer8.setAnswer(cell24.getStringCellValue());
                    }else {
                        answer8.setAnswer(cell23.getStringCellValue());
                    }
                    answer8.setInfoId(dwInfo.getId());
                    answer8.setQuestionId(8L);
                    answers.add(answer8);
                    Cell cell26 = row.getCell(26);
                    if (cell26 != null && StringUtils.isNotEmpty(cell26.getStringCellValue())){
                        DwAnswer answer91 = new DwAnswer();
                        answer91.setAnswer(cell26.getStringCellValue());
                        answer91.setInfoId(dwInfo.getId());
                        answer91.setQuestionId(9L);
                        answers.add(answer91);
                    }
                    Cell cell27 = row.getCell(27);
                    if (cell27 != null && StringUtils.isNotEmpty(cell27.getStringCellValue())){
                        DwAnswer answer92 = new DwAnswer();
                        answer92.setAnswer(cell27.getStringCellValue());
                        answer92.setInfoId(dwInfo.getId());
                        answer92.setQuestionId(9L);
                        answers.add(answer92);
                    }
                    Cell cell28 = row.getCell(28);
                    if (cell28 != null && StringUtils.isNotEmpty(cell28.getStringCellValue())){
                        DwAnswer answer93 = new DwAnswer();
                        answer93.setAnswer(cell28.getStringCellValue());
                        answer93.setInfoId(dwInfo.getId());
                        answer93.setQuestionId(9L);
                        answers.add(answer93);
                    }
                    Cell cell29 = row.getCell(29);
                    if (cell29 != null && StringUtils.isNotEmpty(cell29.getStringCellValue())){
                        DwAnswer answer94 = new DwAnswer();
                        answer94.setAnswer(cell29.getStringCellValue());
                        answer94.setInfoId(dwInfo.getId());
                        answer94.setQuestionId(9L);
                        answers.add(answer94);
                    }
                    Cell cell30 = row.getCell(30);
                    if (cell30 != null && StringUtils.isNotEmpty(cell30.getStringCellValue())){
                        DwAnswer answer95 = new DwAnswer();
                        answer95.setAnswer(cell30.getStringCellValue());
                        answer95.setInfoId(dwInfo.getId());
                        answer95.setQuestionId(9L);
                        answers.add(answer95);
                    }
                    Cell cell31 = row.getCell(31);
                    if (cell31 != null && StringUtils.isNotEmpty(cell31.getStringCellValue())){
                        DwAnswer answer96 = new DwAnswer();
                        answer96.setAnswer(cell31.getStringCellValue());
                        answer96.setInfoId(dwInfo.getId());
                        answer96.setQuestionId(9L);
                        answers.add(answer96);
                    }
                    Cell cell32 = row.getCell(32);
                    if (cell32 != null && StringUtils.isNotEmpty(cell32.getStringCellValue())){
                        DwAnswer answer97 = new DwAnswer();
                        answer97.setAnswer(cell32.getStringCellValue());
                        answer97.setInfoId(dwInfo.getId());
                        answer97.setQuestionId(9L);
                        answers.add(answer97);
                    }
                    Cell cell33 = row.getCell(33);
                    if (cell33 != null && StringUtils.isNotEmpty(cell33.getStringCellValue())){
                        DwAnswer answer98 = new DwAnswer();
                        answer98.setAnswer(cell33.getStringCellValue());
                        answer98.setInfoId(dwInfo.getId());
                        answer98.setQuestionId(9L);
                        answers.add(answer98);
                    }
                    Cell cell35 = row.getCell(35);
                    if (cell35 != null && StringUtils.isNotEmpty(cell35.getStringCellValue())){
                        DwAnswer answer99 = new DwAnswer();
                        answer99.setAnswer(cell35.getStringCellValue());
                        answer99.setInfoId(dwInfo.getId());
                        answer99.setQuestionId(9L);
                        answers.add(answer99);
                    }
                    DwAnswer answer10 = new DwAnswer();
                    Cell cell36 = row.getCell(36);
                    answer10.setAnswer(cell36.getStringCellValue());
                    answer10.setInfoId(dwInfo.getId());
                    answer10.setQuestionId(10L);
                    answers.add(answer10);
                    DwAnswer answer11 = new DwAnswer();
                    Cell cell37 = row.getCell(37);
                    answer11.setAnswer(cell37.getStringCellValue());
                    answer11.setInfoId(dwInfo.getId());
                    answer11.setQuestionId(11L);
                    answers.add(answer11);
                    DwAnswer answer12 = new DwAnswer();
                    Cell cell38 = row.getCell(38);
                    answer12.setAnswer(cell38.getStringCellValue());
                    answer12.setInfoId(dwInfo.getId());
                    answer12.setQuestionId(12L);
                    answers.add(answer12);
                    DwAnswer answer13 = new DwAnswer();
                    Cell cell39 = row.getCell(39);
                    answer13.setAnswer(cell39.getStringCellValue());
                    answer13.setInfoId(dwInfo.getId());
                    answer13.setQuestionId(13L);
                    answers.add(answer13);
                    DwAnswer answer14 = new DwAnswer();
                    Cell cell40 = row.getCell(40);
                    answer14.setAnswer(cell40.getStringCellValue());
                    answer14.setInfoId(dwInfo.getId());
                    answer14.setQuestionId(14L);
                    answers.add(answer14);
                    DwAnswer answer15 = new DwAnswer();
                    Cell cell41 = row.getCell(41);
                    answer15.setAnswer(cell41.getStringCellValue());
                    answer15.setInfoId(dwInfo.getId());
                    answer15.setQuestionId(15L);
                    answers.add(answer15);
                    DwAnswer answer16 = new DwAnswer();
                    Cell cell42 = row.getCell(42);
                    Cell cell43 = row.getCell(43);
                    if (cell43 != null && StringUtils.isNotEmpty(cell43.getStringCellValue())){
                        answer16.setAnswer(cell43.getStringCellValue());
                    }else {
                        answer16.setAnswer(cell42.getStringCellValue());
                    }
                    answer16.setInfoId(dwInfo.getId());
                    answer16.setQuestionId(16L);
                    answers.add(answer16);
                    DwAnswer answer17 = new DwAnswer();
                    Cell cell44 = row.getCell(44);
                    answer17.setAnswer(cell44.getStringCellValue());
                    answer17.setInfoId(dwInfo.getId());
                    answer17.setQuestionId(17L);
                    answers.add(answer17);
                    DwAnswer answer18 = new DwAnswer();
                    Cell cell45 = row.getCell(45);
                    answer18.setAnswer(cell45.getStringCellValue());
                    answer18.setInfoId(dwInfo.getId());
                    answer18.setQuestionId(18L);
                    answers.add(answer18);
                    DwAnswer answer19 = new DwAnswer();
                    Cell cell46 = row.getCell(46);
                    Cell cell47 = row.getCell(47);
                    if (cell47 != null && StringUtils.isNotEmpty(cell47.getStringCellValue())){
                        answer19.setAnswer(cell47.getStringCellValue());
                    }else {
                        answer19.setAnswer(cell46.getStringCellValue());
                    }
                    answer19.setInfoId(dwInfo.getId());
                    answer19.setQuestionId(19L);
                    answers.add(answer19);
                    DwAnswer answer20 = new DwAnswer();
                    Cell cell48 = row.getCell(48);
                    answer20.setAnswer(cell48.getStringCellValue());
                    answer20.setInfoId(dwInfo.getId());
                    answer20.setQuestionId(20L);
                    answers.add(answer20);
                    DwAnswer answer21 = new DwAnswer();
                    Cell cell49 = row.getCell(49);
                    answer21.setAnswer(cell49.getStringCellValue());
                    answer21.setInfoId(dwInfo.getId());
                    answer21.setQuestionId(21L);
                    answers.add(answer21);
                    Cell cell51 = row.getCell(51);
                    if (cell51 != null && StringUtils.isNotEmpty(cell51.getStringCellValue())){
                        DwAnswer answer221 = new DwAnswer();
                        answer221.setAnswer(cell51.getStringCellValue());
                        answer221.setInfoId(dwInfo.getId());
                        answer221.setQuestionId(22L);
                        answers.add(answer221);
                    }
                    Cell cell52 = row.getCell(52);
                    if (cell52 != null && StringUtils.isNotEmpty(cell52.getStringCellValue())){
                        DwAnswer answer222 = new DwAnswer();
                        answer222.setAnswer(cell52.getStringCellValue());
                        answer222.setInfoId(dwInfo.getId());
                        answer222.setQuestionId(22L);
                        answers.add(answer222);
                    }
                    Cell cell53 = row.getCell(53);
                    if (cell53 != null && StringUtils.isNotEmpty(cell53.getStringCellValue())){
                        DwAnswer answer223 = new DwAnswer();
                        answer223.setAnswer(cell53.getStringCellValue());
                        answer223.setInfoId(dwInfo.getId());
                        answer223.setQuestionId(22L);
                        answers.add(answer223);
                    }
                    Cell cell54 = row.getCell(54);
                    if (cell54 != null && StringUtils.isNotEmpty(cell54.getStringCellValue())){
                        DwAnswer answer224 = new DwAnswer();
                        answer224.setAnswer(cell54.getStringCellValue());
                        answer224.setInfoId(dwInfo.getId());
                        answer224.setQuestionId(22L);
                        answers.add(answer224);
                    }
                    Cell cell55 = row.getCell(55);
                    if (cell55 != null && StringUtils.isNotEmpty(cell55.getStringCellValue())){
                        DwAnswer answer225 = new DwAnswer();
                        answer225.setAnswer(cell55.getStringCellValue());
                        answer225.setInfoId(dwInfo.getId());
                        answer225.setQuestionId(22L);
                        answers.add(answer225);
                    }
                    Cell cell56 = row.getCell(56);
                    if (cell56 != null && StringUtils.isNotEmpty(cell56.getStringCellValue())){
                        DwAnswer answer226 = new DwAnswer();
                        answer226.setAnswer(cell56.getStringCellValue());
                        answer226.setInfoId(dwInfo.getId());
                        answer226.setQuestionId(22L);
                        answers.add(answer226);
                    }
                    Cell cell57 = row.getCell(57);
                    if (cell57 != null && StringUtils.isNotEmpty(cell57.getStringCellValue())){
                        DwAnswer answer227 = new DwAnswer();
                        answer227.setAnswer(cell57.getStringCellValue());
                        answer227.setInfoId(dwInfo.getId());
                        answer227.setQuestionId(22L);
                        answers.add(answer227);
                    }
                    Cell cell59 = row.getCell(59);
                    if (cell59 != null && StringUtils.isNotEmpty(cell59.getStringCellValue())){
                        DwAnswer answer228 = new DwAnswer();
                        answer228.setAnswer(cell59.getStringCellValue());
                        answer228.setInfoId(dwInfo.getId());
                        answer228.setQuestionId(22L);
                        answers.add(answer228);
                    }
                    DwAnswer answer23 = new DwAnswer();
                    Cell cell60 = row.getCell(60);
                    answer23.setAnswer(cell60.getStringCellValue());
                    answer23.setInfoId(dwInfo.getId());
                    answer23.setQuestionId(23L);
                    answers.add(answer23);
                    DwAnswer answer24 = new DwAnswer();
                    Cell cell61 = row.getCell(61);
                    answer24.setAnswer(cell61.getStringCellValue());
                    answer24.setInfoId(dwInfo.getId());
                    answer24.setQuestionId(24L);
                    answers.add(answer24);
                    DwAnswer answer25 = new DwAnswer();
                    Cell cell62 = row.getCell(62);
                    Cell cell63 = row.getCell(63);
                    if (cell63 != null && StringUtils.isNotEmpty(cell63.getStringCellValue())){
                        answer25.setAnswer(cell63.getStringCellValue());
                    }else {
                        answer25.setAnswer(cell62.getStringCellValue());
                    }
                    answer25.setInfoId(dwInfo.getId());
                    answer25.setQuestionId(25L);
                    answers.add(answer25);
                    Cell cell65 = row.getCell(65);
                    if (cell65 != null && StringUtils.isNotEmpty(cell65.getStringCellValue())){
                        DwAnswer answer261 = new DwAnswer();
                        answer261.setAnswer(cell65.getStringCellValue());
                        answer261.setInfoId(dwInfo.getId());
                        answer261.setQuestionId(26L);
                        answers.add(answer261);
                    }
                    Cell cell66 = row.getCell(66);
                    if (cell66 != null && StringUtils.isNotEmpty(cell66.getStringCellValue())){
                        DwAnswer answer262 = new DwAnswer();
                        answer262.setAnswer(cell66.getStringCellValue());
                        answer262.setInfoId(dwInfo.getId());
                        answer262.setQuestionId(26L);
                        answers.add(answer262);
                    }
                    Cell cell67 = row.getCell(67);
                    if (cell67 != null && StringUtils.isNotEmpty(cell67.getStringCellValue())){
                        DwAnswer answer263 = new DwAnswer();
                        answer263.setAnswer(cell67.getStringCellValue());
                        answer263.setInfoId(dwInfo.getId());
                        answer263.setQuestionId(26L);
                        answers.add(answer263);
                    }
                    Cell cell68 = row.getCell(68);
                    if (cell68 != null && StringUtils.isNotEmpty(cell68.getStringCellValue())){
                        DwAnswer answer264 = new DwAnswer();
                        answer264.setAnswer(cell68.getStringCellValue());
                        answer264.setInfoId(dwInfo.getId());
                        answer264.setQuestionId(26L);
                        answers.add(answer264);
                    }
                    Cell cell69 = row.getCell(69);
                    if (cell69 != null && StringUtils.isNotEmpty(cell69.getStringCellValue())){
                        DwAnswer answer265 = new DwAnswer();
                        answer265.setAnswer(cell69.getStringCellValue());
                        answer265.setInfoId(dwInfo.getId());
                        answer265.setQuestionId(26L);
                        answers.add(answer265);
                    }
                    Cell cell70 = row.getCell(70);
                    if (cell70 != null && StringUtils.isNotEmpty(cell70.getStringCellValue())){
                        DwAnswer answer266 = new DwAnswer();
                        answer266.setAnswer(cell70.getStringCellValue());
                        answer266.setInfoId(dwInfo.getId());
                        answer266.setQuestionId(26L);
                        answers.add(answer266);
                    }
                    DwAnswer answer27 = new DwAnswer();
                    Cell cell71 = row.getCell(71);
                    answer27.setAnswer(cell71.getStringCellValue());
                    answer27.setInfoId(dwInfo.getId());
                    answer27.setQuestionId(27L);
                    answers.add(answer27);
                    DwAnswer answer28 = new DwAnswer();
                    Cell cell72 = row.getCell(72);
                    Cell cell73 = row.getCell(73);
                    Cell cell74 = row.getCell(74);
                    Cell cell75 = row.getCell(75);
                    Cell cell76 = row.getCell(76);
                    Cell cell77 = row.getCell(77);
                    Cell cell78 = row.getCell(78);
                    Cell cell79 = row.getCell(79);
                    answer28.setAnswer(cell72.getStringCellValue() +","+cell73.getStringCellValue()
                            +","+cell74.getStringCellValue() +","+cell75.getStringCellValue() +","
                            +cell76.getStringCellValue() +","+cell77.getStringCellValue() +","
                            +cell78.getStringCellValue() +","+ cell79.getStringCellValue());
                    answer28.setInfoId(dwInfo.getId());
                    answer28.setQuestionId(28L);
                    answers.add(answer28);
                    DwAnswer answer29 = new DwAnswer();
                    Cell cell80 = row.getCell(80);
                    answer29.setAnswer(cell80.getStringCellValue());
                    answer29.setInfoId(dwInfo.getId());
                    answer29.setQuestionId(29L);
                    answers.add(answer29);
                    DwAnswer answer30 = new DwAnswer();
                    Cell cell81 = row.getCell(81);
                    answer30.setAnswer(cell81.getStringCellValue());
                    answer30.setInfoId(dwInfo.getId());
                    answer30.setQuestionId(30L);
                    answers.add(answer30);
                    DwAnswer answer31 = new DwAnswer();
                    Cell cell82 = row.getCell(82);
                    Cell cell83 = row.getCell(83);
                    answer31.setAnswer(cell82.getStringCellValue() + cell83.getStringCellValue());
                    answer31.setInfoId(dwInfo.getId());
                    answer31.setQuestionId(31L);
                    answers.add(answer31);
                    DwAnswer answer32 = new DwAnswer();
                    Cell cell84 = row.getCell(84);
                    answer32.setAnswer(cell84.getStringCellValue());
                    answer32.setInfoId(dwInfo.getId());
                    answer32.setQuestionId(32L);
                    answers.add(answer32);
                    Cell cell86 = row.getCell(86);
                    if (cell86 != null && StringUtils.isNotEmpty(cell86.getStringCellValue())){
                        DwAnswer answer331 = new DwAnswer();
                        answer331.setAnswer(cell86.getStringCellValue());
                        answer331.setInfoId(dwInfo.getId());
                        answer331.setQuestionId(33L);
                        answers.add(answer331);
                    }
                    Cell cell87 = row.getCell(87);
                    if (cell87 != null && StringUtils.isNotEmpty(cell87.getStringCellValue())){
                        DwAnswer answer332 = new DwAnswer();
                        answer332.setAnswer(cell87.getStringCellValue());
                        answer332.setInfoId(dwInfo.getId());
                        answer332.setQuestionId(33L);
                        answers.add(answer332);
                    }
                    Cell cell88 = row.getCell(88);
                    if (cell88 != null && StringUtils.isNotEmpty(cell88.getStringCellValue())){
                        DwAnswer answer333 = new DwAnswer();
                        answer333.setAnswer(cell88.getStringCellValue());
                        answer333.setInfoId(dwInfo.getId());
                        answer333.setQuestionId(33L);
                        answers.add(answer333);
                    }
                    Cell cell89 = row.getCell(89);
                    if (cell89 != null && StringUtils.isNotEmpty(cell89.getStringCellValue())){
                        DwAnswer answer334 = new DwAnswer();
                        answer334.setAnswer(cell89.getStringCellValue());
                        answer334.setInfoId(dwInfo.getId());
                        answer334.setQuestionId(33L);
                        answers.add(answer334);
                    }
                    Cell cell90 = row.getCell(90);
                    if (cell90 != null && StringUtils.isNotEmpty(cell90.getStringCellValue())){
                        DwAnswer answer335 = new DwAnswer();
                        answer335.setAnswer(cell90.getStringCellValue());
                        answer335.setInfoId(dwInfo.getId());
                        answer335.setQuestionId(33L);
                        answers.add(answer335);
                    }
                    Cell cell91 = row.getCell(91);
                    if (cell91 != null && StringUtils.isNotEmpty(cell91.getStringCellValue())){
                        DwAnswer answer336 = new DwAnswer();
                        answer336.setAnswer(cell91.getStringCellValue());
                        answer336.setInfoId(dwInfo.getId());
                        answer336.setQuestionId(33L);
                        answers.add(answer336);
                    }
                    Cell cell92 = row.getCell(92);
                    if (cell92 != null && StringUtils.isNotEmpty(cell92.getStringCellValue())){
                        DwAnswer answer337 = new DwAnswer();
                        answer337.setAnswer(cell92.getStringCellValue());
                        answer337.setInfoId(dwInfo.getId());
                        answer337.setQuestionId(33L);
                        answers.add(answer337);
                    }
                    Cell cell93 = row.getCell(93);
                    if (cell93 != null && StringUtils.isNotEmpty(cell93.getStringCellValue())){
                        DwAnswer answer338 = new DwAnswer();
                        answer338.setAnswer(cell93.getStringCellValue());
                        answer338.setInfoId(dwInfo.getId());
                        answer338.setQuestionId(33L);
                        answers.add(answer338);
                    }
                    Cell cell94 = row.getCell(94);
                    if (cell94 != null && StringUtils.isNotEmpty(cell94.getStringCellValue())){
                        DwAnswer answer339 = new DwAnswer();
                        answer339.setAnswer(cell94.getStringCellValue());
                        answer339.setInfoId(dwInfo.getId());
                        answer339.setQuestionId(33L);
                        answers.add(answer339);
                    }
                    Cell cell95 = row.getCell(95);
                    if (cell95 != null && StringUtils.isNotEmpty(cell95.getStringCellValue())){
                        DwAnswer answer3310 = new DwAnswer();
                        answer3310.setAnswer(cell95.getStringCellValue());
                        answer3310.setInfoId(dwInfo.getId());
                        answer3310.setQuestionId(33L);
                        answers.add(answer3310);
                    }
                    Cell cell96 = row.getCell(96);
                    if (cell96 != null && StringUtils.isNotEmpty(cell96.getStringCellValue())){
                        DwAnswer answer3311 = new DwAnswer();
                        answer3311.setAnswer(cell96.getStringCellValue());
                        answer3311.setInfoId(dwInfo.getId());
                        answer3311.setQuestionId(33L);
                        answers.add(answer3311);
                    }
                    Cell cell97 = row.getCell(97);
                    if (cell97 != null && StringUtils.isNotEmpty(cell97.getStringCellValue())){
                        DwAnswer answer3312 = new DwAnswer();
                        answer3312.setAnswer(cell97.getStringCellValue());
                        answer3312.setInfoId(dwInfo.getId());
                        answer3312.setQuestionId(33L);
                        answers.add(answer3312);
                    }
                    DwAnswer answer34 = new DwAnswer();
                    Cell cell98 = row.getCell(98);
                    answer34.setAnswer(cell98.getStringCellValue());
                    answer34.setInfoId(dwInfo.getId());
                    answer34.setQuestionId(34L);
                    answers.add(answer34);
                    DwAnswer answer35 = new DwAnswer();
                    Cell cell99 = row.getCell(99);
                    Cell cell100 = row.getCell(100);
                    Cell cell101 = row.getCell(101);
                    Cell cell102 = row.getCell(102);
                    Cell cell103 = row.getCell(103);
                    answer35.setAnswer(cell99.getStringCellValue() +","+cell100.getStringCellValue()
                            +","+cell101.getStringCellValue() +","+cell102.getStringCellValue() +","
                            +cell103.getStringCellValue());
                    answer35.setInfoId(dwInfo.getId());
                    answer35.setQuestionId(35L);
                    answers.add(answer35);
                    Cell cell105 = row.getCell(105);
                    if (cell105 != null && StringUtils.isNotEmpty(cell105.getStringCellValue())){
                        DwAnswer answer361 = new DwAnswer();
                        answer361.setAnswer(cell105.getStringCellValue());
                        answer361.setInfoId(dwInfo.getId());
                        answer361.setQuestionId(36L);
                        answers.add(answer361);
                    }
                    Cell cell106 = row.getCell(106);
                    if (cell106 != null && StringUtils.isNotEmpty(cell106.getStringCellValue())){
                        DwAnswer answer362 = new DwAnswer();
                        answer362.setAnswer(cell106.getStringCellValue());
                        answer362.setInfoId(dwInfo.getId());
                        answer362.setQuestionId(36L);
                        answers.add(answer362);
                    }
                    Cell cell107 = row.getCell(107);
                    if (cell107 != null && StringUtils.isNotEmpty(cell107.getStringCellValue())){
                        DwAnswer answer363 = new DwAnswer();
                        answer363.setAnswer(cell107.getStringCellValue());
                        answer363.setInfoId(dwInfo.getId());
                        answer363.setQuestionId(36L);
                        answers.add(answer363);
                    }
                    Cell cell108 = row.getCell(108);
                    if (cell108 != null && StringUtils.isNotEmpty(cell108.getStringCellValue())){
                        DwAnswer answer364 = new DwAnswer();
                        answer364.setAnswer(cell108.getStringCellValue());
                        answer364.setInfoId(dwInfo.getId());
                        answer364.setQuestionId(36L);
                        answers.add(answer364);
                    }
                    Cell cell109 = row.getCell(109);
                    if (cell109 != null && StringUtils.isNotEmpty(cell109.getStringCellValue())){
                        DwAnswer answer365 = new DwAnswer();
                        answer365.setAnswer(cell109.getStringCellValue());
                        answer365.setInfoId(dwInfo.getId());
                        answer365.setQuestionId(36L);
                        answers.add(answer365);
                    }
                    Cell cell110 = row.getCell(110);
                    if (cell110 != null && StringUtils.isNotEmpty(cell110.getStringCellValue())){
                        DwAnswer answer366 = new DwAnswer();
                        answer366.setAnswer(cell110.getStringCellValue());
                        answer366.setInfoId(dwInfo.getId());
                        answer366.setQuestionId(36L);
                        answers.add(answer366);
                    }
                    Cell cell111 = row.getCell(111);
                    if (cell111 != null && StringUtils.isNotEmpty(cell111.getStringCellValue())){
                        DwAnswer answer367 = new DwAnswer();
                        answer367.setAnswer(cell111.getStringCellValue());
                        answer367.setInfoId(dwInfo.getId());
                        answer367.setQuestionId(36L);
                        answers.add(answer367);
                    }
                    Cell cell112 = row.getCell(112);
                    if (cell112 != null && StringUtils.isNotEmpty(cell112.getStringCellValue())){
                        DwAnswer answer368 = new DwAnswer();
                        answer368.setAnswer(cell112.getStringCellValue());
                        answer368.setInfoId(dwInfo.getId());
                        answer368.setQuestionId(36L);
                        answers.add(answer368);
                    }
                    Cell cell113 = row.getCell(113);
                    if (cell113 != null && StringUtils.isNotEmpty(cell113.getStringCellValue())){
                        DwAnswer answer369 = new DwAnswer();
                        answer369.setAnswer(cell113.getStringCellValue());
                        answer369.setInfoId(dwInfo.getId());
                        answer369.setQuestionId(36L);
                        answers.add(answer369);
                    }
                    Cell cell114 = row.getCell(114);
                    if (cell114 != null && StringUtils.isNotEmpty(cell114.getStringCellValue())){
                        DwAnswer answer3610 = new DwAnswer();
                        answer3610.setAnswer(cell114.getStringCellValue());
                        answer3610.setInfoId(dwInfo.getId());
                        answer3610.setQuestionId(36L);
                        answers.add(answer3610);
                    }
                    Cell cell115 = row.getCell(115);
                    if (cell115 != null && StringUtils.isNotEmpty(cell115.getStringCellValue())){
                        DwAnswer answer3611 = new DwAnswer();
                        answer3611.setAnswer(cell115.getStringCellValue());
                        answer3611.setInfoId(dwInfo.getId());
                        answer3611.setQuestionId(36L);
                        answers.add(answer3611);

                    }
                    Cell cell116 = row.getCell(116);
                    if (cell116 != null && StringUtils.isNotEmpty(cell116.getStringCellValue())){
                        DwAnswer answer3612 = new DwAnswer();
                        answer3612.setAnswer(cell116.getStringCellValue());
                        answer3612.setInfoId(dwInfo.getId());
                        answer3612.setQuestionId(36L);
                        answers.add(answer3612);
                    }
                    Cell cell117 = row.getCell(117);
                    if (cell117 != null && StringUtils.isNotEmpty(cell117.getStringCellValue())){
                        DwAnswer answer3613 = new DwAnswer();
                        answer3613.setAnswer(cell117.getStringCellValue());
                        answer3613.setInfoId(dwInfo.getId());
                        answer3613.setQuestionId(36L);
                        answers.add(answer3613);
                    }
                    Cell cell118 = row.getCell(118);
                    if (cell118 != null && StringUtils.isNotEmpty(cell118.getStringCellValue())){
                        DwAnswer answer3614 = new DwAnswer();
                        answer3614.setAnswer(cell118.getStringCellValue());
                        answer3614.setInfoId(dwInfo.getId());
                        answer3614.setQuestionId(36L);
                        answers.add(answer3614);
                    }
                    Cell cell120 = row.getCell(120);
                    if (cell120 != null && StringUtils.isNotEmpty(cell120.getStringCellValue())){
                        DwAnswer answer3615 = new DwAnswer();
                        answer3615.setAnswer(cell120.getStringCellValue());
                        answer3615.setInfoId(dwInfo.getId());
                        answer3615.setQuestionId(36L);
                        answers.add(answer3615);
                    }
                    DwAnswer answer37 = new DwAnswer();
                    Cell cell121 = row.getCell(121);
                    Cell cell122 = row.getCell(122);
                    Cell cell123 = row.getCell(123);
                    Cell cell124 = row.getCell(124);
                    Cell cell125 = row.getCell(125);
                    Cell cell126 = row.getCell(126);
                    Cell cell127 = row.getCell(127);
                    Cell cell128 = row.getCell(128);
                    answer37.setAnswer(cell121.getStringCellValue() +","+cell122.getStringCellValue()
                            +","+cell123.getStringCellValue() +","+cell124.getStringCellValue() +","
                            +","+cell125.getStringCellValue() +","+cell126.getStringCellValue() +","
                            +","+cell127.getStringCellValue() +","+cell128.getStringCellValue() );
                    answer37.setInfoId(dwInfo.getId());
                    answer37.setQuestionId(37L);
                    answers.add(answer37);
                    Cell cell130 = row.getCell(130);
                    if (cell130 != null && StringUtils.isNotEmpty(cell130.getStringCellValue())){
                        DwAnswer answer381 = new DwAnswer();
                        answer381.setAnswer(cell130.getStringCellValue());
                        answer381.setInfoId(dwInfo.getId());
                        answer381.setQuestionId(38L);
                        answers.add(answer381);
                    }
                    Cell cell131 = row.getCell(131);
                    if (cell131 != null && StringUtils.isNotEmpty(cell131.getStringCellValue())){
                        DwAnswer answer382 = new DwAnswer();
                        answer382.setAnswer(cell131.getStringCellValue());
                        answer382.setInfoId(dwInfo.getId());
                        answer382.setQuestionId(38L);
                        answers.add(answer382);
                    }
                    Cell cell132 = row.getCell(132);
                    if (cell132 != null && StringUtils.isNotEmpty(cell132.getStringCellValue())){
                        DwAnswer answer383 = new DwAnswer();
                        answer383.setAnswer(cell132.getStringCellValue());
                        answer383.setInfoId(dwInfo.getId());
                        answer383.setQuestionId(38L);
                        answers.add(answer383);
                    }
                    Cell cell133 = row.getCell(133);
                    if (cell133 != null && StringUtils.isNotEmpty(cell133.getStringCellValue())){
                        DwAnswer answer384 = new DwAnswer();
                        answer384.setAnswer(cell133.getStringCellValue());
                        answer384.setInfoId(dwInfo.getId());
                        answer384.setQuestionId(38L);
                        answers.add(answer384);
                    }
                    Cell cell134 = row.getCell(134);
                    if (cell134 != null && StringUtils.isNotEmpty(cell134.getStringCellValue())){
                        DwAnswer answer385 = new DwAnswer();
                        answer385.setAnswer(cell134.getStringCellValue());
                        answer385.setInfoId(dwInfo.getId());
                        answer385.setQuestionId(38L);
                        answers.add(answer385);
                    }
                    Cell cell135 = row.getCell(135);
                    if (cell135 != null && StringUtils.isNotEmpty(cell135.getStringCellValue())){
                        DwAnswer answer386 = new DwAnswer();
                        answer386.setAnswer(cell135.getStringCellValue());
                        answer386.setInfoId(dwInfo.getId());
                        answer386.setQuestionId(38L);
                        answers.add(answer386);
                    }
                    DwAnswer answer39 = new DwAnswer();
                    Cell cell136 = row.getCell(136);
                    answer39.setAnswer(cell136.getStringCellValue());
                    answer39.setInfoId(dwInfo.getId());
                    answer39.setQuestionId(39L);
                    answers.add(answer39);
                    DwAnswer answer40 = new DwAnswer();
                    Cell cell137 = row.getCell(137);
                    Cell cell138 = row.getCell(138);
                    Cell cell139 = row.getCell(139);
                    Cell cell140 = row.getCell(140);
                    answer40.setAnswer(cell137.getStringCellValue() +","+cell138.getStringCellValue()
                            +","+cell139.getStringCellValue() +","+cell140.getStringCellValue() );
                    answer40.setInfoId(dwInfo.getId());
                    answer40.setQuestionId(40L);
                    answers.add(answer40);
                    DwAnswer answer41 = new DwAnswer();
                    Cell cell141 = row.getCell(141);
                    Cell cell142 = row.getCell(142);
                    Cell cell143 = row.getCell(143);
                    Cell cell144 = row.getCell(144);
                    Cell cell145 = row.getCell(145);
                    Cell cell146 = row.getCell(146);
                    answer41.setAnswer(cell141.getStringCellValue() +","+cell142.getStringCellValue()
                            +","+cell143.getStringCellValue() +","+cell144.getStringCellValue() +","
                            +","+cell145.getStringCellValue() +","+cell146.getStringCellValue());
                    answer41.setInfoId(dwInfo.getId());
                    answer41.setQuestionId(41L);
                    answers.add(answer41);
                }else if (dwInfo.getId() == 2) {
                    DwAnswer answer1 = new DwAnswer();
                    Cell cell15 = row.getCell(15);
                    answer1.setAnswer(cell15.getStringCellValue());
                    answer1.setInfoId(dwInfo.getId());
                    answer1.setQuestionId(42L);
                    answers.add(answer1);
                    DwAnswer answer2 = new DwAnswer();
                    Cell cell16 = row.getCell(16);
                    answer2.setAnswer(cell16.getStringCellValue());
                    answer2.setInfoId(dwInfo.getId());
                    answer2.setQuestionId(43L);
                    answers.add(answer2);
                    DwAnswer answer3 = new DwAnswer();
                    Cell cell17 = row.getCell(17);
                    Cell cell18 = row.getCell(18);
                    if (cell18 != null && StringUtils.isNotEmpty(cell18.getStringCellValue())) {
                        answer3.setAnswer(cell18.getStringCellValue());
                    }else {
                        answer3.setAnswer(cell17.getStringCellValue());
                    }
                    answer3.setInfoId(dwInfo.getId());
                    answer3.setQuestionId(44L);
                    answers.add(answer3);
                    DwAnswer answer4 = new DwAnswer();
                    Cell cell19 = row.getCell(19);
                    answer4.setAnswer(cell19.getStringCellValue());
                    answer4.setInfoId(dwInfo.getId());
                    answer4.setQuestionId(45L);
                    answers.add(answer4);
                    DwAnswer answer5 = new DwAnswer();
                    Cell cell20 = row.getCell(20);
                    answer5.setAnswer(cell20.getStringCellValue());
                    answer5.setInfoId(dwInfo.getId());
                    answer5.setQuestionId(46L);
                    answers.add(answer5);
                    DwAnswer answer6 = new DwAnswer();
                    Cell cell21 = row.getCell(21);
                    answer6.setAnswer(cell21.getStringCellValue());
                    answer6.setInfoId(dwInfo.getId());
                    answer6.setQuestionId(47L);
                    answers.add(answer6);
                    DwAnswer answer7 = new DwAnswer();
                    Cell cell22 = row.getCell(22);
                    Cell cell23 = row.getCell(23);
                    if (cell23 != null && StringUtils.isNotEmpty(cell23.getStringCellValue())) {
                        answer7.setAnswer(cell23.getStringCellValue());
                    }else {
                        answer7.setAnswer(cell22.getStringCellValue());
                    }
                    answer7.setInfoId(dwInfo.getId());
                    answer7.setQuestionId(48L);
                    answers.add(answer7);
                    DwAnswer answer8 = new DwAnswer();
                    Cell cell24 = row.getCell(24);
                    answer8.setAnswer(cell24.getStringCellValue());
                    answer8.setInfoId(dwInfo.getId());
                    answer8.setQuestionId(49L);
                    answers.add(answer8);
                    DwAnswer answer9 = new DwAnswer();
                    Cell cell25 = row.getCell(25);
                    answer9.setAnswer(cell25.getStringCellValue());
                    answer9.setInfoId(dwInfo.getId());
                    answer9.setQuestionId(50L);
                    answers.add(answer9);
                    Cell cell27 = row.getCell(27);
                    if (cell27 != null && StringUtils.isNotEmpty(cell27.getStringCellValue())) {
                        DwAnswer answer101 = new DwAnswer();
                        answer101.setAnswer(cell27.getStringCellValue());
                        answer101.setInfoId(dwInfo.getId());
                        answer101.setQuestionId(51L);
                        answers.add(answer101);
                    }
                    Cell cell28 = row.getCell(28);
                    if (cell28 != null && StringUtils.isNotEmpty(cell28.getStringCellValue())) {
                        DwAnswer answer102 = new DwAnswer();
                        answer102.setAnswer(cell28.getStringCellValue());
                        answer102.setInfoId(dwInfo.getId());
                        answer102.setQuestionId(51L);
                        answers.add(answer102);
                    }
                    Cell cell29 = row.getCell(29);
                    if (cell29 != null && StringUtils.isNotEmpty(cell29.getStringCellValue())) {
                        DwAnswer answer103 = new DwAnswer();
                        answer103.setAnswer(cell29.getStringCellValue());
                        answer103.setInfoId(dwInfo.getId());
                        answer103.setQuestionId(51L);
                        answers.add(answer103);
                    }
                    Cell cell30 = row.getCell(30);
                    if (cell30 != null && StringUtils.isNotEmpty(cell30.getStringCellValue())) {
                        DwAnswer answer104 = new DwAnswer();
                        answer104.setAnswer(cell30.getStringCellValue());
                        answer104.setInfoId(dwInfo.getId());
                        answer104.setQuestionId(51L);
                        answers.add(answer104);
                    }
                    Cell cell31 = row.getCell(31);
                    if (cell31 != null && StringUtils.isNotEmpty(cell31.getStringCellValue())) {
                        DwAnswer answer105 = new DwAnswer();
                        answer105.setAnswer(cell31.getStringCellValue());
                        answer105.setInfoId(dwInfo.getId());
                        answer105.setQuestionId(51L);
                        answers.add(answer105);
                    }
                    Cell cell32 = row.getCell(32);
                    if (cell32 != null && StringUtils.isNotEmpty(cell32.getStringCellValue())) {
                        DwAnswer answer106 = new DwAnswer();
                        answer106.setAnswer(cell32.getStringCellValue());
                        answer106.setInfoId(dwInfo.getId());
                        answer106.setQuestionId(51L);
                        answers.add(answer106);
                    }
                    Cell cell33 = row.getCell(33);
                    if (cell33 != null && StringUtils.isNotEmpty(cell33.getStringCellValue())) {
                        DwAnswer answer107 = new DwAnswer();
                        answer107.setAnswer(cell33.getStringCellValue());
                        answer107.setInfoId(dwInfo.getId());
                        answer107.setQuestionId(51L);
                        answers.add(answer107);
                    }
                    Cell cell34 = row.getCell(34);
                    if (cell34 != null && StringUtils.isNotEmpty(cell34.getStringCellValue())) {
                        DwAnswer answer108 = new DwAnswer();
                        answer108.setAnswer(cell34.getStringCellValue());
                        answer108.setInfoId(dwInfo.getId());
                        answer108.setQuestionId(51L);
                        answers.add(answer108);
                    }
                    Cell cell35 = row.getCell(35);
                    if (cell35 != null && StringUtils.isNotEmpty(cell35.getStringCellValue())) {
                        DwAnswer answer109 = new DwAnswer();
                        answer109.setAnswer(cell35.getStringCellValue());
                        answer109.setInfoId(dwInfo.getId());
                        answer109.setQuestionId(51L);
                        answers.add(answer109);
                    }
                    Cell cell36 = row.getCell(36);
                    if (cell36 != null && StringUtils.isNotEmpty(cell36.getStringCellValue())) {
                        DwAnswer answer110 = new DwAnswer();
                        answer110.setAnswer(cell36.getStringCellValue());
                        answer110.setInfoId(dwInfo.getId());
                        answer110.setQuestionId(51L);
                        answers.add(answer110);
                    }
                    Cell cell37 = row.getCell(37);
                    if (cell37 != null && StringUtils.isNotEmpty(cell37.getStringCellValue())) {
                        DwAnswer answer111 = new DwAnswer();
                        answer111.setAnswer(cell37.getStringCellValue());
                        answer111.setInfoId(dwInfo.getId());
                        answer111.setQuestionId(51L);
                        answers.add(answer111);
                    }
                    Cell cell38 = row.getCell(38);
                    if (cell38 != null && StringUtils.isNotEmpty(cell38.getStringCellValue())) {
                        DwAnswer answer112 = new DwAnswer();
                        answer112.setAnswer(cell38.getStringCellValue());
                        answer112.setInfoId(dwInfo.getId());
                        answer112.setQuestionId(51L);
                        answers.add(answer112);
                    }
                    DwAnswer answer11 = new DwAnswer();
                    Cell cell39 = row.getCell(39);
                    answer11.setAnswer(cell39.getStringCellValue());
                    answer11.setInfoId(dwInfo.getId());
                    answer11.setQuestionId(52L);
                    answers.add(answer11);
                    DwAnswer answer12 = new DwAnswer();
                    Cell cell40 = row.getCell(40);
                    answer12.setAnswer(cell40.getStringCellValue());
                    answer12.setInfoId(dwInfo.getId());
                    answer12.setQuestionId(53L);
                    answers.add(answer12);
                    DwAnswer answer13 = new DwAnswer();
                    Cell cell41 = row.getCell(41);
                    Cell cell42 = row.getCell(42);
                    Cell cell43 = row.getCell(43);
                    answer13.setAnswer(cell41.getStringCellValue() + ","+cell42.getStringCellValue()
                            + "," +cell43.getStringCellValue());
                    answer13.setInfoId(dwInfo.getId());
                    answer13.setQuestionId(54L);
                    answers.add(answer13);
                    DwAnswer answer14 = new DwAnswer();
                    Cell cell44 = row.getCell(44);
                    answer14.setAnswer(cell44.getStringCellValue());
                    answer14.setInfoId(dwInfo.getId());
                    answer14.setQuestionId(55L);
                    answers.add(answer14);
                    DwAnswer answer15 = new DwAnswer();
                    Cell cell45 = row.getCell(45);
                    Cell cell46 = row.getCell(46);
                    if (cell45 != null && cell45.getStringCellValue().equals("否")){
                        answer15.setAnswer("否");
                    }else {
                        answer15.setAnswer(cell46.getStringCellValue());
                    }
                    answer15.setInfoId(dwInfo.getId());
                    answer15.setQuestionId(56L);
                    answers.add(answer15);
                    DwAnswer answer16 = new DwAnswer();
                    Cell cell47 = row.getCell(47);
                    answer16.setAnswer(cell47.getStringCellValue());
                    answer16.setInfoId(dwInfo.getId());
                    answer16.setQuestionId(57L);
                    answers.add(answer16);
                    DwAnswer answer17 = new DwAnswer();
                    Cell cell48 = row.getCell(48);
                    Cell cell49 = row.getCell(49);
                    Cell cell50 = row.getCell(50);
                    answer17.setAnswer(cell48.getStringCellValue() + "," +cell49.getStringCellValue()
                            + "," +cell50.getStringCellValue());
                    answer17.setInfoId(dwInfo.getId());
                    answer17.setQuestionId(58L);
                    answers.add(answer17);
                    Cell cell52 = row.getCell(52);
                    if (cell52 != null && StringUtils.isNotEmpty(cell52.getStringCellValue())) {
                        DwAnswer answer181 = new DwAnswer();
                        answer181.setAnswer(cell52.getStringCellValue());
                        answer181.setInfoId(dwInfo.getId());
                        answer181.setQuestionId(59L);
                        answers.add(answer181);
                    }
                    Cell cell53 = row.getCell(53);
                    if (cell53 != null && StringUtils.isNotEmpty(cell53.getStringCellValue())) {
                        DwAnswer answer181 = new DwAnswer();
                        answer181.setAnswer(cell53.getStringCellValue());
                        answer181.setInfoId(dwInfo.getId());
                        answer181.setQuestionId(59L);
                        answers.add(answer181);
                    }
                    Cell cell54 = row.getCell(54);
                    if (cell54 != null && StringUtils.isNotEmpty(cell54.getStringCellValue())) {
                        DwAnswer answer182 = new DwAnswer();
                        answer182.setAnswer(cell54.getStringCellValue());
                        answer182.setInfoId(dwInfo.getId());
                        answer182.setQuestionId(59L);
                        answers.add(answer182);
                    }
                    Cell cell55 = row.getCell(55);
                    if (cell55 != null && StringUtils.isNotEmpty(cell55.getStringCellValue())) {
                        DwAnswer answer183 = new DwAnswer();
                        answer183.setAnswer(cell55.getStringCellValue());
                        answer183.setInfoId(dwInfo.getId());
                        answer183.setQuestionId(59L);
                        answers.add(answer183);
                    }
                    Cell cell56 = row.getCell(56);
                    if (cell56 != null && StringUtils.isNotEmpty(cell56.getStringCellValue())) {
                        DwAnswer answer184 = new DwAnswer();
                        answer184.setAnswer(cell56.getStringCellValue());
                        answer184.setInfoId(dwInfo.getId());
                        answer184.setQuestionId(59L);
                        answers.add(answer184);
                    }
                    Cell cell57 = row.getCell(57);
                    if (cell57 != null && StringUtils.isNotEmpty(cell57.getStringCellValue())) {
                        DwAnswer answer185 = new DwAnswer();
                        answer185.setAnswer(cell57.getStringCellValue());
                        answer185.setInfoId(dwInfo.getId());
                        answer185.setQuestionId(59L);
                        answers.add(answer185);
                    }
                    Cell cell59 = row.getCell(59);
                    if (cell59 != null && StringUtils.isNotEmpty(cell59.getStringCellValue())) {
                        DwAnswer answer186 = new DwAnswer();
                        answer186.setAnswer(cell59.getStringCellValue());
                        answer186.setInfoId(dwInfo.getId());
                        answer186.setQuestionId(59L);
                        answers.add(answer186);
                    }
                    Cell cell61 = row.getCell(61);
                    if (cell61 != null && StringUtils.isNotEmpty(cell61.getStringCellValue())) {
                        DwAnswer answer191 = new DwAnswer();
                        answer191.setAnswer(cell61.getStringCellValue());
                        answer191.setInfoId(dwInfo.getId());
                        answer191.setQuestionId(60L);
                        answers.add(answer191);
                    }
                    Cell cell62 = row.getCell(62);
                    if (cell62 != null && StringUtils.isNotEmpty(cell62.getStringCellValue())) {
                        DwAnswer answer192 = new DwAnswer();
                        answer192.setAnswer(cell62.getStringCellValue());
                        answer192.setInfoId(dwInfo.getId());
                        answer192.setQuestionId(60L);
                        answers.add(answer192);
                    }
                    Cell cell63 = row.getCell(63);
                    if (cell63 != null && StringUtils.isNotEmpty(cell63.getStringCellValue())) {
                        DwAnswer answer193 = new DwAnswer();
                        answer193.setAnswer(cell63.getStringCellValue());
                        answer193.setInfoId(dwInfo.getId());
                        answer193.setQuestionId(60L);
                        answers.add(answer193);
                    }
                    Cell cell64 = row.getCell(64);
                    if (cell64 != null && StringUtils.isNotEmpty(cell64.getStringCellValue())) {
                        DwAnswer answer194 = new DwAnswer();
                        answer194.setAnswer(cell64.getStringCellValue());
                        answer194.setInfoId(dwInfo.getId());
                        answer194.setQuestionId(60L);
                        answers.add(answer194);
                    }
                    Cell cell65 = row.getCell(65);
                    if (cell65 != null && StringUtils.isNotEmpty(cell65.getStringCellValue())) {
                        DwAnswer answer195 = new DwAnswer();
                        answer195.setAnswer(cell65.getStringCellValue());
                        answer195.setInfoId(dwInfo.getId());
                        answer195.setQuestionId(60L);
                        answers.add(answer195);
                    }
                    Cell cell66 = row.getCell(66);
                    if (cell66 != null && StringUtils.isNotEmpty(cell66.getStringCellValue())) {
                        DwAnswer answer196 = new DwAnswer();
                        answer196.setAnswer(cell66.getStringCellValue());
                        answer196.setInfoId(dwInfo.getId());
                        answer196.setQuestionId(60L);
                        answers.add(answer196);
                    }
                    Cell cell67 = row.getCell(67);
                    if (cell67 != null && StringUtils.isNotEmpty(cell67.getStringCellValue())) {
                        DwAnswer answer197 = new DwAnswer();
                        answer197.setAnswer(cell67.getStringCellValue());
                        answer197.setInfoId(dwInfo.getId());
                        answer197.setQuestionId(60L);
                        answers.add(answer197);
                    }
                    Cell cell69 = row.getCell(69);
                    if (cell69 != null && StringUtils.isNotEmpty(cell69.getStringCellValue())) {
                        DwAnswer answer201 = new DwAnswer();
                        answer201.setAnswer(cell69.getStringCellValue());
                        answer201.setInfoId(dwInfo.getId());
                        answer201.setQuestionId(61L);
                        answers.add(answer201);
                    }
                    Cell cell70 = row.getCell(70);
                    if (cell70 != null && StringUtils.isNotEmpty(cell70.getStringCellValue())) {
                        DwAnswer answer202 = new DwAnswer();
                        answer202.setAnswer(cell70.getStringCellValue());
                        answer202.setInfoId(dwInfo.getId());
                        answer202.setQuestionId(61L);
                        answers.add(answer202);
                    }
                    Cell cell71 = row.getCell(71);
                    if (cell71 != null && StringUtils.isNotEmpty(cell71.getStringCellValue())) {
                        DwAnswer answer203 = new DwAnswer();
                        answer203.setAnswer(cell71.getStringCellValue());
                        answer203.setInfoId(dwInfo.getId());
                        answer203.setQuestionId(61L);
                        answers.add(answer203);
                    }
                    Cell cell72 = row.getCell(72);
                    if (cell72 != null && StringUtils.isNotEmpty(cell72.getStringCellValue())) {
                        DwAnswer answer204 = new DwAnswer();
                        answer204.setAnswer(cell72.getStringCellValue());
                        answer204.setInfoId(dwInfo.getId());
                        answer204.setQuestionId(61L);
                        answers.add(answer204);
                    }
                    Cell cell73 = row.getCell(73);
                    if (cell73 != null && StringUtils.isNotEmpty(cell73.getStringCellValue())) {
                        DwAnswer answer205 = new DwAnswer();
                        answer205.setAnswer(cell73.getStringCellValue());
                        answer205.setInfoId(dwInfo.getId());
                        answer205.setQuestionId(61L);
                        answers.add(answer205);
                    }
                    Cell cell74 = row.getCell(74);
                    if (cell74 != null && StringUtils.isNotEmpty(cell74.getStringCellValue())) {
                        DwAnswer answer206 = new DwAnswer();
                        answer206.setAnswer(cell74.getStringCellValue());
                        answer206.setInfoId(dwInfo.getId());
                        answer206.setQuestionId(61L);
                        answers.add(answer206);
                    }
                    Cell cell76 = row.getCell(76);
                    if (cell76 != null && StringUtils.isNotEmpty(cell76.getStringCellValue())) {
                        DwAnswer answer207 = new DwAnswer();
                        answer207.setAnswer(cell76.getStringCellValue());
                        answer207.setInfoId(dwInfo.getId());
                        answer207.setQuestionId(61L);
                        answers.add(answer207);
                    }
                    DwAnswer answer21 = new DwAnswer();
                    Cell cell77 = row.getCell(77);
                    answer21.setAnswer(cell77.getStringCellValue());
                    answer21.setInfoId(dwInfo.getId());
                    answer21.setQuestionId(62L);
                    answers.add(answer21);
                    DwAnswer answer22 = new DwAnswer();
                    Cell cell79 = row.getCell(79);
                    answer22.setAnswer(cell79.getStringCellValue());
                    answer22.setInfoId(dwInfo.getId());
                    answer22.setQuestionId(63L);
                    answers.add(answer22);
                    DwAnswer answer23 = new DwAnswer();
                    Cell cell80 = row.getCell(80);
                    Cell cell81 = row.getCell(81);
                    if (cell81 != null && StringUtils.isNotEmpty(cell81.getStringCellValue())){
                        answer23.setAnswer(cell81.getStringCellValue());
                    }else {
                        answer23.setAnswer(cell80.getStringCellValue());
                    }
                    answer23.setInfoId(dwInfo.getId());
                    answer23.setQuestionId(64L);
                    answers.add(answer23);
                    DwAnswer answer24 = new DwAnswer();
                    Cell cell82 = row.getCell(82);
                    answer24.setAnswer(cell82.getStringCellValue());
                    answer24.setInfoId(dwInfo.getId());
                    answer24.setQuestionId(65L);
                    answers.add(answer24);
                }else if (dwInfo.getId() == 3) {
                    DwAnswer answer1 = new DwAnswer();
                    Cell cell15 = row.getCell(15);
                    answer1.setAnswer(cell15.getStringCellValue());
                    answer1.setInfoId(dwInfo.getId());
                    answer1.setQuestionId(66L);
                    answers.add(answer1);
                    DwAnswer answer2 = new DwAnswer();
                    Cell cell16 = row.getCell(16);
                    answer2.setAnswer(cell16.getStringCellValue());
                    answer2.setInfoId(dwInfo.getId());
                    answer2.setQuestionId(67L);
                    answers.add(answer2);
                    DwAnswer answer3 = new DwAnswer();
                    Cell cell17 = row.getCell(17);
                    answer3.setAnswer(cell17.getStringCellValue());
                    answer3.setInfoId(dwInfo.getId());
                    answer3.setQuestionId(68L);
                    answers.add(answer3);
                    DwAnswer answer4 = new DwAnswer();
                    Cell cell18 = row.getCell(18);
                    answer4.setAnswer(cell18.getStringCellValue());
                    answer4.setInfoId(dwInfo.getId());
                    answer4.setQuestionId(69L);
                    answers.add(answer4);
                    DwAnswer answer5 = new DwAnswer();
                    Cell cell19 = row.getCell(19);
                    answer5.setAnswer(cell19.getStringCellValue());
                    answer5.setInfoId(dwInfo.getId());
                    answer5.setQuestionId(70L);
                    answers.add(answer5);
                    DwAnswer answer6 = new DwAnswer();
                    Cell cell20 = row.getCell(20);
                    answer6.setAnswer(cell20.getStringCellValue());
                    answer6.setInfoId(dwInfo.getId());
                    answer6.setQuestionId(71L);
                    answers.add(answer6);
                    DwAnswer answer7 = new DwAnswer();
                    Cell cell21 = row.getCell(21);
                    answer7.setAnswer(cell21.getStringCellValue());
                    answer7.setInfoId(dwInfo.getId());
                    answer7.setQuestionId(72L);
                    answers.add(answer7);
                    DwAnswer answer8 = new DwAnswer();
                    Cell cell22 = row.getCell(22);
                    answer8.setAnswer(cell22.getStringCellValue());
                    answer8.setInfoId(dwInfo.getId());
                    answer8.setQuestionId(73L);
                    answers.add(answer8);
                    DwAnswer answer9 = new DwAnswer();
                    Cell cell23 = row.getCell(23);
                    answer9.setAnswer(cell23.getStringCellValue());
                    answer9.setInfoId(dwInfo.getId());
                    answer9.setQuestionId(74L);
                    answers.add(answer9);
                    Cell cell25 = row.getCell(25);
                    if (cell25 != null && StringUtils.isNotEmpty(cell25.getStringCellValue())){
                        DwAnswer answer101 = new DwAnswer();
                        answer101.setAnswer(cell25.getStringCellValue());
                        answer101.setInfoId(dwInfo.getId());
                        answer101.setQuestionId(75L);
                        answers.add(answer101);
                    }
                    Cell cell26 = row.getCell(26);
                    if (cell26 != null && StringUtils.isNotEmpty(cell26.getStringCellValue())){
                        DwAnswer answer102 = new DwAnswer();
                        answer102.setAnswer(cell26.getStringCellValue());
                        answer102.setInfoId(dwInfo.getId());
                        answer102.setQuestionId(75L);
                        answers.add(answer102);
                    }
                    Cell cell27 = row.getCell(27);
                    if (cell27 != null && StringUtils.isNotEmpty(cell27.getStringCellValue())){
                        DwAnswer answer103 = new DwAnswer();
                        answer103.setAnswer(cell27.getStringCellValue());
                        answer103.setInfoId(dwInfo.getId());
                        answer103.setQuestionId(75L);
                        answers.add(answer103);
                    }
                    Cell cell28 = row.getCell(28);
                    if (cell28 != null && StringUtils.isNotEmpty(cell28.getStringCellValue())){
                        DwAnswer answer104 = new DwAnswer();
                        answer104.setAnswer(cell28.getStringCellValue());
                        answer104.setInfoId(dwInfo.getId());
                        answer104.setQuestionId(75L);
                        answers.add(answer104);
                    }
                    Cell cell29 = row.getCell(29);
                    if (cell29 != null && StringUtils.isNotEmpty(cell29.getStringCellValue())){
                        DwAnswer answer105 = new DwAnswer();
                        answer105.setAnswer(cell29.getStringCellValue());
                        answer105.setInfoId(dwInfo.getId());
                        answer105.setQuestionId(75L);
                        answers.add(answer105);
                    }
                    Cell cell31 = row.getCell(31);
                    if (cell31 != null && StringUtils.isNotEmpty(cell31.getStringCellValue())){
                        DwAnswer answer106 = new DwAnswer();
                        answer106.setAnswer(cell31.getStringCellValue());
                        answer106.setInfoId(dwInfo.getId());
                        answer106.setQuestionId(75L);
                        answers.add(answer106);
                    }
                    Cell cell33 = row.getCell(33);
                    if (cell33!=null && StringUtils.isNotEmpty(cell33.getStringCellValue())){
                        DwAnswer answer107 = new DwAnswer();
                        answer107.setAnswer(cell33.getStringCellValue());
                        answer107.setInfoId(dwInfo.getId());
                        answer107.setQuestionId(75L);
                        answers.add(answer107);
                    }
                    DwAnswer answer11 = new DwAnswer();
                    Cell cell34 = row.getCell(34);
                    Cell cell35 = row.getCell(35);
                    if (cell35 != null && StringUtils.isNotEmpty(cell35.getStringCellValue())){
                        answer11.setAnswer(cell35.getStringCellValue());
                    }else {
                        answer11.setAnswer(cell34.getStringCellValue());
                    }
                    answer11.setInfoId(dwInfo.getId());
                    answer11.setQuestionId(76L);
                    answers.add(answer11);
                    DwAnswer answer12 = new DwAnswer();
                    Cell cell36 = row.getCell(36);
                    answer12.setAnswer(cell36.getStringCellValue());
                    answer12.setInfoId(dwInfo.getId());
                    answer12.setQuestionId(77L);
                    answers.add(answer12);
                    DwAnswer answer13 = new DwAnswer();
                    Cell cell37 = row.getCell(37);
                    Cell cell38 = row.getCell(38);
                    if (cell38 != null && StringUtils.isNotEmpty(cell38.getStringCellValue())){
                        answer13.setAnswer(cell38.getStringCellValue());
                    }else {
                        answer13.setAnswer(cell37.getStringCellValue());
                    }
                    answer13.setInfoId(dwInfo.getId());
                    answer13.setQuestionId(78L);
                    answers.add(answer13);
                    DwAnswer answer14 = new DwAnswer();
                    Cell cell39 = row.getCell(39);
                    answer14.setAnswer(cell39.getStringCellValue());
                    answer14.setInfoId(dwInfo.getId());
                    answer14.setQuestionId(79L);
                    answers.add(answer14);
                    Cell cell41 = row.getCell(41);
                    Cell cell42 = row.getCell(42);
                    Cell cell43 = row.getCell(43);
                    Cell cell44 = row.getCell(44);
                    Cell cell45 = row.getCell(45);
                    Cell cell47 = row.getCell(47);
                    if (cell41 != null && StringUtils.isNotEmpty(cell41.getStringCellValue())){
                        DwAnswer answer151 = new DwAnswer();
                        answer151.setAnswer(cell41.getStringCellValue());
                        answer151.setInfoId(dwInfo.getId());
                        answer151.setQuestionId(80L);
                    }
                    if (cell42 != null && StringUtils.isNotEmpty(cell42.getStringCellValue())){
                        DwAnswer answer152 = new DwAnswer();
                        answer152.setAnswer(cell42.getStringCellValue());
                        answer152.setInfoId(dwInfo.getId());
                        answer152.setQuestionId(80L);
                        answers.add(answer152);
                    }
                    if (cell43 != null && StringUtils.isNotEmpty(cell43.getStringCellValue())){
                        DwAnswer answer153 = new DwAnswer();
                        answer153.setAnswer(cell43.getStringCellValue());
                        answer153.setInfoId(dwInfo.getId());
                        answer153.setQuestionId(80L);
                        answers.add(answer153);
                    }
                    if (cell44 != null && StringUtils.isNotEmpty(cell44.getStringCellValue())){
                        DwAnswer answer154 = new DwAnswer();
                        answer154.setAnswer(cell44.getStringCellValue());
                        answer154.setInfoId(dwInfo.getId());
                        answer154.setQuestionId(80L);
                        answers.add(answer154);
                    }
                    if (cell45 != null && StringUtils.isNotEmpty(cell45.getStringCellValue())){
                        DwAnswer answer155 = new DwAnswer();
                        answer155.setAnswer(cell45.getStringCellValue());
                        answer155.setInfoId(dwInfo.getId());
                        answer155.setQuestionId(80L);
                        answers.add(answer155);
                    }
                    if (cell47 != null && StringUtils.isNotEmpty(cell47.getStringCellValue())){
                        DwAnswer answer156 = new DwAnswer();
                        answer156.setAnswer(cell47.getStringCellValue());
                        answer156.setInfoId(dwInfo.getId());
                        answer156.setQuestionId(80L);
                        answers.add(answer156);
                    }
                    DwAnswer answer16 = new DwAnswer();
                    Cell cell48 = row.getCell(48);
                    answer16.setAnswer(cell48.getStringCellValue());
                    answer16.setInfoId(dwInfo.getId());
                    answer16.setQuestionId(81L);
                    answers.add(answer16);
                    Cell cell50 = row.getCell(50);
                    if (cell50!=null && StringUtils.isNotEmpty(cell50.getStringCellValue())){
                        DwAnswer answer171 = new DwAnswer();
                        answer171.setAnswer(cell50.getStringCellValue());
                        answer171.setInfoId(dwInfo.getId());
                        answer171.setQuestionId(82L);
                        answers.add(answer171);
                    }
                    Cell cell51 = row.getCell(51);
                    if (cell51!=null && StringUtils.isNotEmpty(cell51.getStringCellValue())){
                        DwAnswer answer172 = new DwAnswer();
                        answer172.setAnswer(cell51.getStringCellValue());
                        answer172.setInfoId(dwInfo.getId());
                        answer172.setQuestionId(82L);
                        answers.add(answer172);
                    }
                    Cell cell52 = row.getCell(52);
                    if (cell52!=null && StringUtils.isNotEmpty(cell52.getStringCellValue())){
                        DwAnswer answer173 = new DwAnswer();
                        answer173.setAnswer(cell52.getStringCellValue());
                        answer173.setInfoId(dwInfo.getId());
                        answer173.setQuestionId(82L);
                        answers.add(answer173);
                    }
                    Cell cell53 = row.getCell(53);
                    if (cell53!=null && StringUtils.isNotEmpty(cell53.getStringCellValue())){
                        DwAnswer answer174 = new DwAnswer();
                        answer174.setAnswer(cell53.getStringCellValue());
                        answer174.setInfoId(dwInfo.getId());
                        answer174.setQuestionId(82L);
                        answers.add(answer174);
                    }
                    Cell cell55 = row.getCell(55);
                    if (cell55!=null && StringUtils.isNotEmpty(cell55.getStringCellValue())){
                        DwAnswer answer175 = new DwAnswer();
                        answer175.setAnswer(cell55.getStringCellValue());
                        answer175.setInfoId(dwInfo.getId());
                        answer175.setQuestionId(82L);
                        answers.add(answer175);
                    }
                    Cell cell57 = row.getCell(57);
                    if (cell57!=null && StringUtils.isNotEmpty(cell57.getStringCellValue())){
                        DwAnswer answer181 = new DwAnswer();
                        answer181.setAnswer(cell57.getStringCellValue());
                        answer181.setInfoId(dwInfo.getId());
                        answer181.setQuestionId(83L);
                        answers.add(answer181);
                    }
                    Cell cell58 = row.getCell(58);
                    if (cell58!=null && StringUtils.isNotEmpty(cell58.getStringCellValue())){
                        DwAnswer answer182 = new DwAnswer();
                        answer182.setAnswer(cell58.getStringCellValue());
                        answer182.setInfoId(dwInfo.getId());
                        answer182.setQuestionId(83L);
                        answers.add(answer182);
                    }
                    Cell cell59 = row.getCell(59);
                    if (cell59!=null && StringUtils.isNotEmpty(cell59.getStringCellValue())){
                        DwAnswer answer183 = new DwAnswer();
                        answer183.setAnswer(cell59.getStringCellValue());
                        answer183.setInfoId(dwInfo.getId());
                        answer183.setQuestionId(83L);
                        answers.add(answer183);
                    }
                    Cell cell60 = row.getCell(60);
                    if (cell60!=null && StringUtils.isNotEmpty(cell60.getStringCellValue())){
                        DwAnswer answer184 = new DwAnswer();
                        answer184.setAnswer(cell60.getStringCellValue());
                        answer184.setInfoId(dwInfo.getId());
                        answer184.setQuestionId(83L);
                        answers.add(answer184);
                    }
                    Cell cell61 = row.getCell(61);
                    if (cell61!=null && StringUtils.isNotEmpty(cell61.getStringCellValue())){
                        DwAnswer answer185 = new DwAnswer();
                        answer185.setAnswer(cell61.getStringCellValue());
                        answer185.setInfoId(dwInfo.getId());
                        answer185.setQuestionId(83L);
                        answers.add(answer185);
                    }
                    Cell cell62 = row.getCell(62);
                    if (cell62!=null && StringUtils.isNotEmpty(cell62.getStringCellValue())){
                        DwAnswer answer186 = new DwAnswer();
                        answer186.setAnswer(cell62.getStringCellValue());
                        answer186.setInfoId(dwInfo.getId());
                        answer186.setQuestionId(83L);
                        answers.add(answer186);
                    }
                    Cell cell64 = row.getCell(64);
                    if (cell64!=null && StringUtils.isNotEmpty(cell64.getStringCellValue())){
                        DwAnswer answer191 = new DwAnswer();
                        answer191.setAnswer(cell64.getStringCellValue());
                        answer191.setInfoId(dwInfo.getId());
                        answer191.setQuestionId(84L);
                        answers.add(answer191);
                    }
                    Cell cell65 = row.getCell(65);
                    if (cell65!=null && StringUtils.isNotEmpty(cell65.getStringCellValue())){
                        DwAnswer answer192 = new DwAnswer();
                        answer192.setAnswer(cell65.getStringCellValue());
                        answer192.setInfoId(dwInfo.getId());
                        answer192.setQuestionId(84L);
                        answers.add(answer192);
                    }
                    Cell cell66 = row.getCell(66);
                    if (cell66!=null && StringUtils.isNotEmpty(cell66.getStringCellValue())){
                        DwAnswer answer193 = new DwAnswer();
                        answer193.setAnswer(cell66.getStringCellValue());
                        answer193.setInfoId(dwInfo.getId());
                        answer193.setQuestionId(84L);
                        answers.add(answer193);
                    }
                    Cell cell67 = row.getCell(67);
                    if (cell67!=null && StringUtils.isNotEmpty(cell67.getStringCellValue())){
                        DwAnswer answer194 = new DwAnswer();
                        answer194.setAnswer(cell67.getStringCellValue());
                        answer194.setInfoId(dwInfo.getId());
                        answer194.setQuestionId(84L);
                        answers.add(answer194);
                    }
                    Cell cell68 = row.getCell(68);
                    if (cell68!=null && StringUtils.isNotEmpty(cell68.getStringCellValue())){
                        DwAnswer answer195 = new DwAnswer();
                        answer195.setAnswer(cell68.getStringCellValue());
                        answer195.setInfoId(dwInfo.getId());
                        answer195.setQuestionId(84L);
                        answers.add(answer195);
                    }
                    Cell cell69 = row.getCell(69);
                    if (cell69!=null && StringUtils.isNotEmpty(cell69.getStringCellValue())){
                        DwAnswer answer196 = new DwAnswer();
                        answer196.setAnswer(cell69.getStringCellValue());
                        answer196.setInfoId(dwInfo.getId());
                        answer196.setQuestionId(84L);
                        answers.add(answer196);
                    }
                    DwAnswer answer20 = new DwAnswer();
                    Cell cell70 = row.getCell(70);
                    answer20.setAnswer(cell70.getStringCellValue());
                    answer20.setInfoId(dwInfo.getId());
                    answer20.setQuestionId(85L);
                    answers.add(answer20);
                    Cell cell72 = row.getCell(72);
                    Cell cell73 = row.getCell(73);
                    Cell cell74 = row.getCell(74);
                    Cell cell75 = row.getCell(75);
                    Cell cell76 = row.getCell(76);
                    Cell cell78 = row.getCell(78);
                    if (cell72 != null && StringUtils.isNotEmpty(cell72.getStringCellValue())){
                        DwAnswer answer211 = new DwAnswer();
                        answer211.setAnswer(cell72.getStringCellValue());
                        answer211.setInfoId(dwInfo.getId());
                        answer211.setQuestionId(86L);
                        answers.add(answer211);
                    }
                    if (cell73 != null && StringUtils.isNotEmpty(cell73.getStringCellValue())){
                        DwAnswer answer212 = new DwAnswer();
                        answer212.setAnswer(cell73.getStringCellValue());
                        answer212.setInfoId(dwInfo.getId());
                        answer212.setQuestionId(86L);
                        answers.add(answer212);
                    }
                    if (cell74 != null && StringUtils.isNotEmpty(cell74.getStringCellValue())){
                        DwAnswer answer213 = new DwAnswer();
                        answer213.setAnswer(cell74.getStringCellValue());
                        answer213.setInfoId(dwInfo.getId());
                        answer213.setQuestionId(86L);
                        answers.add(answer213);
                    }
                    if (cell75 != null && StringUtils.isNotEmpty(cell75.getStringCellValue())){
                        DwAnswer answer214 = new DwAnswer();
                        answer214.setAnswer(cell75.getStringCellValue());
                        answer214.setInfoId(dwInfo.getId());
                        answer214.setQuestionId(86L);
                        answers.add(answer214);
                    }
                    if (cell76 != null && StringUtils.isNotEmpty(cell76.getStringCellValue())){
                        DwAnswer answer215 = new DwAnswer();
                        answer215.setAnswer(cell76.getStringCellValue());
                        answer215.setInfoId(dwInfo.getId());
                        answer215.setQuestionId(86L);
                        answers.add(answer215);
                    }
                    if (cell78 != null && StringUtils.isNotEmpty(cell78.getStringCellValue())){
                        DwAnswer answer216 = new DwAnswer();
                        answer216.setAnswer(cell78.getStringCellValue());
                        answer216.setInfoId(dwInfo.getId());
                        answer216.setQuestionId(86L);
                        answers.add(answer216);
                    }
                    DwAnswer answer22 = new DwAnswer();
                    Cell cell79 = row.getCell(79);
                    answer22.setAnswer(cell79.getStringCellValue());
                    answer22.setInfoId(dwInfo.getId());
                    answer22.setQuestionId(87L);
                    answers.add(answer22);
                }else {
                    return -2;
                }
                redisCache.setCacheObject(id, true);
            }
            dwAnswerMapper.insertDwAnswerBatch(answers);
            return rows;
        }catch (Exception ex){
            ex.printStackTrace();
            return -1;
        }
    }

}
